| tabpfn-package | R Documentation |
Provides a consistent API for classification and regression models based on the 'TabPFN' model of Hollmann et al. (2025), "Accurate predictions on small data with a tabular foundation model," Nature, 637(8045) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1038/s41586-024-08328-6")}. The calculations are served via 'Python' to train and predict the model.
Maintainer: Max Kuhn max@posit.co (ORCID)
Other contributors:
Posit Software, PBC (ROR) [copyright holder, funder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.